@@ -55,6 +55,9 @@ debci_sendmail_from="${debci_sendmail_from:-$debci_distro_name Continuous Integr
 debci_sendmail_to="${debci_sendmail_to:-%s@localhost}"
 debci_url_base="${debci_url_base:-http://localhost:8080}"
 debci_artifacts_url_base="${debci_artifacts_url_base:-}"
+debci_database_url="${debci_database_url:-sqlite3://$debci_data_basedir/debci.sqlite3}"
+
+debci_secrets_dir=${debci_secrets_dir:-$(readlink -f "${debci_base_dir}/secrets")}
 
 shared_short_options='c:s:a:b:d:hq'
 shared_long_options='config:,suite:,arch:,backend:,data-dir:,amqp:,help,quiet'
@@ -125,20 +128,17 @@ for arg in "$@"; do
   fi
 done
 
-alias prepare_args='while [ "$1" != '--' ]; do shift; done; shift'
+alias prepare_args='while [ "$1" != "--" ]; do shift; done; shift'
 
 debci_autopkgtest_dir="${debci_data_basedir}/autopkgtest/${debci_suite}/${debci_arch}"
-debci_autopkgtest_incoming_dir="${debci_data_basedir}/autopkgtest-incoming/${debci_suite}/${debci_arch}"
+debci_autopkgtest_incoming_basedir="${debci_data_basedir}/autopkgtest-incoming"
+debci_autopkgtest_incoming_dir="${debci_autopkgtest_incoming_basedir}/${debci_suite}/${debci_arch}"
 debci_packages_dir="${debci_data_basedir}/packages/${debci_suite}/${debci_arch}"
 debci_status_dir="${debci_data_basedir}/status/${debci_suite}/${debci_arch}"
 debci_html_dir="${debci_data_basedir}/.html"
 
 debci_gnupg_dir="${debci_base_dir}/gnupg"
 
-debci_chroots_dir="${debci_base_dir}/chroots"
-debci_chroot_name="debci-${debci_suite}-${debci_arch}"
-debci_chroot_path="${debci_chroots_dir}/${debci_chroot_name}"
-
 debci_bin_dir="${debci_base_dir}/bin"
 
 debci_log_dir="${debci_base_dir}/log"
@@ -147,7 +147,7 @@ debci_user=$(stat -c %U "${debci_data_basedir}")
 debci_uid=$(stat -c %u "${debci_data_basedir}")
 debci_group=$(stat -c %G "${debci_data_basedir}")
 
-debci_amqp_queue=${debci_amqp_queue:-"debci-${debci_arch}-${debci_backend}"}
+debci_amqp_queue=${debci_amqp_queue:-"debci-tests-${debci_arch}-${debci_backend}"}
 
 debci_lock_dir=${debci_lock_dir:-/var/lock}
 
@@ -163,6 +163,9 @@ debci_generate_index_lock=${debci_lock_dir}/debci-generate-index.lock
 # data retention policy (numbers of days)
 debci_data_retention_days=180
 
+# extra arguments for autopkgtest
+debci_autopkgtest_args="${debci_autopkgtest_args:-}"
+
 
 for dir in \
   "${debci_base_dir}/backends/${debci_backend}" \
